@@ -4,8 +4,8 @@ use strict;
 use warnings;
 
 BEGIN {
-    our $VERSION    = '0.58';
-    our @EXPORT_OK  = qw[ decode_utf8 encode_utf8 ];
+    our $VERSION    = '0.60';
+    our @EXPORT_OK  = qw[ decode_utf8 encode_utf8 valid_utf8 ];
     our %EXPORT_TAGS = (
         all => [ @EXPORT_OK ],
     );
